@@ -15,10 +15,13 @@
  */
 package org.drools.workbench.screens.scenariosimulation.client.widgets;
 
+import java.util.Collections;
 import java.util.List;
 import java.util.stream.IntStream;
 
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
+import com.google.gwt.event.shared.EventBus;
+import org.drools.workbench.screens.scenariosimulation.client.events.EnableRightPanelEvent;
 import org.drools.workbench.screens.scenariosimulation.client.factories.ScenarioHeaderTextBoxSingletonDOMElementFactory;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationGridWidgetMouseEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.metadata.ScenarioHeaderMetaData;
@@ -32,14 +35,18 @@ import org.drools.workbench.screens.scenariosimulation.model.FactIdentifier;
 import org.drools.workbench.screens.scenariosimulation.model.FactMapping;
 import org.drools.workbench.screens.scenariosimulation.model.FactMappingType;
 import org.drools.workbench.screens.scenariosimulation.model.Scenario;
+import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
 import org.drools.workbench.screens.scenariosimulation.model.Simulation;
 import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn.ColumnWidthMode;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.NodeMouseEventHandler;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.DefaultGridWidgetCellSelectorMouseEventHandler;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.SelectionExtension;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -48,6 +55,8 @@ import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -58,13 +67,13 @@ import static org.mockito.Mockito.when;
 public class ScenarioGridTest {
 
     @Mock
-    private ScenarioGridModel mockScenarioGridModel;
+    private ScenarioGridModel scenarioGridModelMock;
     @Mock
-    private ScenarioGridLayer mockScenarioGridLayer;
+    private ScenarioGridLayer scenarioGridLayerMock;
     @Mock
-    private ScenarioGridRenderer mockScenarioGridRenderer;
+    private ScenarioGridRenderer scenarioGridRendererMock;
     @Mock
-    private ScenarioGridPanel mockScenarioGridPanel;
+    private ScenarioGridPanel scenarioGridPanelMock;
     @Mock
     private ScenarioHeaderTextBoxSingletonDOMElementFactory scenarioHeaderTextBoxSingletonDOMElementFactoryMock;
     @Mock
@@ -73,16 +82,20 @@ public class ScenarioGridTest {
     private ScenarioGridColumn scenarioGridColumnMock;
     @Mock
     private ScenarioHeaderMetaData propertyHeaderMetadataMock;
+    @Mock
+    private EventBus eventBusMock;
 
-    private final FactMappingType factMappingType = FactMappingType.valueOf("OTHER");
     private final String EXPRESSION_ALIAS_DESCRIPTION = "EXPRESSION_ALIAS_DESCRIPTION";
     private final String EXPRESSION_ALIAS_GIVEN = "EXPRESSION_ALIAS_GIVEN";
+    private final String EXPRESSION_ALIAS_INTEGER = "EXPRESSION_ALIAS_INTEGER";
     private final String EXPRESSION_ALIAS_INDEX = "EXPRESSION_ALIAS_INDEX";
 
     private FactMapping factMappingDescription;
     private FactMapping factMappingIndex;
     private FactMapping factMappingGiven;
+    private FactMapping factMappingInteger;
     private FactIdentifier factIdentifierGiven;
+    private FactIdentifier factIdentifierInteger;
 
     private Simulation simulation = new Simulation();
 
@@ -94,11 +107,13 @@ public class ScenarioGridTest {
     public void setup() {
         when(scenarioGridColumnMock.getPropertyHeaderMetaData()).thenReturn(propertyHeaderMetadataMock);
         factIdentifierGiven = new FactIdentifier("GIVEN", "GIVEN");
+        factIdentifierInteger = new FactIdentifier("Integer", "java.lang.Integer");
         factMappingDescription = new FactMapping(EXPRESSION_ALIAS_DESCRIPTION, FactIdentifier.DESCRIPTION, ExpressionIdentifier.DESCRIPTION);
         factMappingGiven = new FactMapping(EXPRESSION_ALIAS_GIVEN, factIdentifierGiven, new ExpressionIdentifier("GIVEN", FactMappingType.GIVEN));
+        factMappingInteger = new FactMapping(EXPRESSION_ALIAS_INTEGER, factIdentifierInteger, new ExpressionIdentifier("GIVEN", FactMappingType.GIVEN));
         factMappingIndex = new FactMapping(EXPRESSION_ALIAS_INDEX, FactIdentifier.INDEX, ExpressionIdentifier.INDEX);
         simulation = getSimulation();
-        scenarioGrid = spy(new ScenarioGrid(mockScenarioGridModel, mockScenarioGridLayer, mockScenarioGridRenderer, mockScenarioGridPanel) {
+        scenarioGrid = spy(new ScenarioGrid(scenarioGridModelMock, scenarioGridLayerMock, scenarioGridRendererMock) {
 
             @Override
             protected void appendRow(int rowIndex, Scenario scenario) {
@@ -106,12 +121,8 @@ public class ScenarioGridTest {
             }
 
             @Override
-            protected ScenarioHeaderTextBoxSingletonDOMElementFactory getScenarioHeaderTextBoxSingletonDOMElementFactory() {
-                return scenarioHeaderTextBoxSingletonDOMElementFactoryMock;
-            }
-
-            @Override
-            protected ScenarioSimulationBuilders.HeaderBuilder getHeaderBuilderLocal(String instanceTitle, String propertyTitle, String columnId, String columnGroup, FactMappingType factMappingType, ScenarioHeaderTextBoxSingletonDOMElementFactory factoryHeader) {
+            protected ScenarioSimulationBuilders.HeaderBuilder getHeaderBuilderLocal(String instanceTitle, String
+                    propertyTitle, String columnId, String columnGroup, FactMappingType factMappingType) {
                 return headerBuilderMock;
             }
 
@@ -120,12 +131,13 @@ public class ScenarioGridTest {
                 return scenarioGridColumnMock;
             }
         });
+        scenarioGrid.setEventBus(eventBusMock);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testDefaultNodeMouseClickHandlers() {
-        final List<NodeMouseEventHandler> handlers = scenarioGrid.getNodeMouseClickEventHandlers(mockScenarioGridLayer);
+        final List<NodeMouseEventHandler> handlers = scenarioGrid.getNodeMouseClickEventHandlers(scenarioGridLayerMock);
 
         assertEquals(1, handlers.size());
         assertTrue(handlers.get(0) instanceof DefaultGridWidgetCellSelectorMouseEventHandler);
@@ -134,8 +146,8 @@ public class ScenarioGridTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testDefaultNodeMouseDoubleClickHandlers() {
-        final List<NodeMouseEventHandler> handlers = scenarioGrid.getNodeMouseDoubleClickEventHandlers(mockScenarioGridLayer,
-                                                                                                       mockScenarioGridLayer);
+        final List<NodeMouseEventHandler> handlers = scenarioGrid.getNodeMouseDoubleClickEventHandlers(scenarioGridLayerMock,
+                                                                                                       scenarioGridLayerMock);
 
         assertEquals(1, handlers.size());
         assertTrue(handlers.get(0) instanceof ScenarioSimulationGridWidgetMouseEventHandler);
@@ -144,8 +156,8 @@ public class ScenarioGridTest {
     @Test
     public void setContent() {
         scenarioGrid.setContent(simulation);
-        verify(mockScenarioGridModel, times(1)).clear();
-        verify(mockScenarioGridModel, times(1)).bindContent(eq(simulation));
+        verify(scenarioGridModelMock, times(1)).clear();
+        verify(scenarioGridModelMock, times(1)).bindContent(eq(simulation));
         verify(scenarioGrid, times(1)).setHeaderColumns(eq(simulation));
         verify(scenarioGrid, times(1)).appendRows(eq(simulation));
     }
@@ -153,7 +165,7 @@ public class ScenarioGridTest {
     @Test
     public void setHeaderColumns() {
         scenarioGrid.setHeaderColumns(simulation);
-        verify(scenarioGrid, times(COLUMNS)).setHeaderColumn(anyInt(), isA(FactMapping.class));
+        verify(scenarioGrid, times(COLUMNS)).setHeaderColumn(anyInt(), isA(FactMapping.class), eq(true));
     }
 
     @Test
@@ -161,7 +173,7 @@ public class ScenarioGridTest {
         String columnId = factMappingDescription.getExpressionIdentifier().getName();
         FactMappingType type = factMappingDescription.getExpressionIdentifier().getType();
         String columnGroup = type.name();
-        scenarioGrid.setHeaderColumn(1, factMappingDescription);
+        scenarioGrid.setHeaderColumn(1, factMappingDescription, true);
         verify(scenarioGrid, times(1)).isPropertyAssigned(eq(true), eq(factMappingDescription));
         verify(scenarioGrid, times(1)).getPlaceholder(eq(true));
         verify(scenarioGrid, times(1)).getScenarioGridColumnLocal(eq(EXPRESSION_ALIAS_DESCRIPTION),
@@ -170,11 +182,15 @@ public class ScenarioGridTest {
                                                                   eq(columnGroup),
                                                                   eq(type),
                                                                   eq(ScenarioSimulationEditorConstants.INSTANCE.insertValue()));
+        verify(scenarioGridColumnMock, times(1)).setColumnWidthMode(ColumnWidthMode.FIXED);
+
         reset(scenarioGrid);
+        reset(scenarioGridColumnMock);
+        reset(scenarioGridModelMock);
         columnId = factMappingGiven.getExpressionIdentifier().getName();
         type = factMappingGiven.getExpressionIdentifier().getType();
         columnGroup = type.name();
-        scenarioGrid.setHeaderColumn(1, factMappingGiven);
+        scenarioGrid.setHeaderColumn(1, factMappingGiven, true);
         verify(scenarioGrid, times(1)).isPropertyAssigned(eq(true), eq(factMappingGiven));
         verify(scenarioGrid, times(1)).getPlaceholder(eq(false));
         verify(scenarioGrid, times(1)).getScenarioGridColumnLocal(eq(EXPRESSION_ALIAS_GIVEN),
@@ -183,6 +199,7 @@ public class ScenarioGridTest {
                                                                   eq(columnGroup),
                                                                   eq(type),
                                                                   eq(ScenarioSimulationEditorConstants.INSTANCE.defineValidType()));
+        verify(scenarioGridColumnMock, never()).setColumnWidthMode(any());
     }
 
     @Test
@@ -193,13 +210,11 @@ public class ScenarioGridTest {
         final FactMappingType type = factMappingDescription.getExpressionIdentifier().getType();
         String columnGroup = type.name();
         scenarioGrid.getScenarioGridColumnLocal(instanceTitle, propertyTitle, columnId, columnGroup, type, ScenarioSimulationEditorConstants.INSTANCE.insertValue());
-        verify(scenarioGrid, times(1)).getScenarioHeaderTextBoxSingletonDOMElementFactory();
         verify(scenarioGrid, times(1)).getHeaderBuilderLocal(eq(instanceTitle),
                                                              eq(propertyTitle),
                                                              eq(columnId),
                                                              eq(columnGroup),
-                                                             eq(type),
-                                                             eq(scenarioHeaderTextBoxSingletonDOMElementFactoryMock));
+                                                             eq(type));
     }
 
     @Test
@@ -224,6 +239,9 @@ public class ScenarioGridTest {
         factMappingGiven.getExpressionElements().add(new ExpressionElement("test"));
         assertFalse(scenarioGrid.isPropertyAssigned(false, factMappingGiven));
         assertTrue(scenarioGrid.isPropertyAssigned(true, factMappingGiven));
+        factMappingInteger.getExpressionElements().clear();
+        assertFalse(scenarioGrid.isPropertyAssigned(false, factMappingInteger));
+        assertTrue(scenarioGrid.isPropertyAssigned(true, factMappingInteger));
     }
 
     @Test
@@ -238,9 +256,30 @@ public class ScenarioGridTest {
         verify(scenarioGrid, times(1)).appendRow(anyInt(), isA(Scenario.class));
     }
 
+    @Test
+    public void testAdjustSelection() {
+        final int uiColumnIndex = 0;
+        final int uiRowIndex = 0;
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(uiColumnIndex);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Collections.singletonList(columnMock));
+
+        final GridData.SelectedCell selectedHeaderCell = mock(GridData.SelectedCell.class);
+        when(selectedHeaderCell.getColumnIndex()).thenReturn(uiColumnIndex);
+        when(selectedHeaderCell.getRowIndex()).thenReturn(uiRowIndex);
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(Collections.singletonList(selectedHeaderCell));
+
+        scenarioGrid.adjustSelection(mock(SelectionExtension.class), false);
+
+        verify(scenarioGrid).signalRightPanelAboutSelectedHeaderCells();
+        verify(scenarioGrid).setSelectedColumnAndHeader(uiRowIndex, uiColumnIndex);
+        verify(eventBusMock).fireEvent(any(EnableRightPanelEvent.class));
+    }
+
     private Simulation getSimulation() {
         Simulation toReturn = new Simulation();
         SimulationDescriptor simulationDescriptor = toReturn.getSimulationDescriptor();
+        simulationDescriptor.setType(ScenarioSimulationModel.Type.RULE);
 
         simulationDescriptor.addFactMapping(FactIdentifier.INDEX.getName(), FactIdentifier.INDEX, ExpressionIdentifier.INDEX);
         simulationDescriptor.addFactMapping(FactIdentifier.DESCRIPTION.getName(), FactIdentifier.DESCRIPTION, ExpressionIdentifier.DESCRIPTION);
